<img src="./flarefly_logo.png" width="200" /> <sub><sup>Logo by Andrea Sofia Triolo</sup></sub>

[![](https://img.shields.io/github/license/flarefly/flarefly)](https://github.com/hipe4ml/hipe4ml-converter/blob/main/LICENSE)
[![](https://img.shields.io/pypi/pyversions/flarefly.svg?longCache=True)](https://pypi.org/project/flarefly/)
[![](https://img.shields.io/pypi/v/flarefly.svg?maxAge=3600)](https://pypi.org/project/flarefly/)
![](https://github.com/hipe4ml/flarefly/actions/workflows/pythonpackage.yml/badge.svg?branch=main)
![](https://github.com/hipe4ml/flarefly/actions/workflows/pythonpublish.yml/badge.svg)
[![Test package](https://github.com/flarefly/flarefly/actions/workflows/pythonpackage.yml/badge.svg)](https://github.com/flarefly/flarefly/actions/workflows/pythonpackage.yml)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7579656.svg)](https://doi.org/10.5281/zenodo.7579656)

# Introduction
FLexible And REliable Fitting LibrarY is a library to perform fits to distributions for particle physics analysis

# Documentation

[https://flarefly.github.io/flarefly/index.html](https://flarefly.github.io/flarefly/index.html)

# Install in-development package

To install the in-development package, from the repository base directory:

```bash
pip install -e .[dev]
```

# Tutorial

If you want to get familiar with flarefly, the following tutorial is available:

| Type | Link |
| -------------- | ------------- |
| Binned invariant mass fit |  [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/flarefly/flarefly/blob/main/tutorials/flarefly_tutorial_Bzero.ipynb) |